class LineWorksException(Exception):
    pass


class LogicException(LineWorksException):
    pass


class LoginException(LineWorksException):
    pass


class GetMyInfoException(LineWorksException):
    pass


class SendMessageException(LineWorksException):
    pass
